@@ -483,6 +483,7 @@ cl_preprocessor_deps_opts = ["/EP", "-EP", "/E", "-E", "/P", "-P"]
 
 requires_value = {
     "CC": set(gcc_opts + clang_opts),
+    "CXX": set(gcc_opts + clang_opts),
     "LD": set(ld_gnu_opts + ld_osx_opts),
     "AS": set(as_gnu_opts + as_osx_opts),
     "Objcopy": set(objcopy_opts),
@@ -512,7 +513,8 @@ gcc_optimization_opts = [
 ]
 
 cif_supported_opts = (
-    ["-D", "-U", "-nostdinc", "-fshort-wchar", "-std", "--std"]
+    ["-D", "-U", "-nostdinc", "-fshort-wchar", "-std", "--std", "-c"]
+    + ["-mbig-endian", "-mlittle-endian", "-mabi"]  # arm
     + ["{}$".format(opt) for opt in gcc_optimization_opts]
     + cif_include_opts
 )
